LARVA - PersonaSpec Manager

#

model
side_effect_policy
can_spawn
spec_version
[auto]
TOOLS
MODEL PARAMETERS
DESCRIPTION
PROMPT
COMPACTION PROMPT (optional)

## Select a persona from the sidebar

## No personas registered

Register your first persona to get started

# Component Library

Import PersonaSpec
Paste PersonaSpec JSON
Assemble Persona
Persona ID
ID must be lowercase kebab-case (e.g. my-agent-name)
Prompts
No prompt components found. Add .md files to ~/.larva/components/prompts/
Toolsets
No toolset components found
Constraints
No constraint components found
Model
No model components found